@@ -56,10 +56,12 @@ typedef struct _GdMainViewPrivate GdMainViewPrivate;
 
 typedef enum {
   GD_MAIN_COLUMN_ID,
+  GD_MAIN_COLUMN_URI,
   GD_MAIN_COLUMN_TITLE,
   GD_MAIN_COLUMN_AUTHOR,
   GD_MAIN_COLUMN_ICON,
-  GD_MAIN_COLUMN_MTIME
+  GD_MAIN_COLUMN_MTIME,
+  GD_MAIN_COLUMN_SELECTED
 } GdMainColumns;
 
 typedef enum {
@@ -88,6 +90,8 @@ void gd_main_view_set_selection_mode (GdMainView *self,
                                       gboolean selection_mode);
 GdMainViewType gd_main_view_get_selection_mode (GdMainView *self);
 
+GList * gd_main_view_get_selection (GdMainView *self);
+
 GtkTreeModel * gd_main_view_get_model (GdMainView *self);
 void gd_main_view_set_model (GdMainView *self,
                              GtkTreeModel *model);
